@@ -4,9 +4,9 @@ from flask import Markup
 
 class TwitterOEmbedder(object):
 
-    def __init__(self, app=None, cache=None, debug=None):
+    def __init__(self, app=None, cache=None, timeout=None, debug=None):
         if app and cache:
-            self.init(app, cache, debug)
+            self.init(app, cache, timeout, debug)
 
     def init(self, app, cache, timeout=None, debug=None):
         twitter_timeout = 60*60*24*365
